## 0.1.13.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 0.1.13.6 (2023-11-11)

third-party: make some protocol params pos-only (#11006)

## 0.1.13.5 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.1.13.4 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 0.1.13.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.1.13.2 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.1.13.1 (2022-11-17)

click_spinner: make arguments optional (#9220)

Matches the code, where these arguments are not required: https://github.com/click-contrib/click-spinner/blob/master/click_spinner/__init__.py

## 0.1.13 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 0.1.12 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 0.1.11 (2022-04-27)

Drop Python 2 support from click-spinner (#7710)

## 0.1.10 (2022-02-03)

Improve `__enter__` & constructor methods (#7114)

## 0.1.9 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.1.7 (2021-12-17)

Always import Protocol from typing in stubs (#6617)

## 0.1.6 (2021-10-12)

Add star to all non-0.1 versions (#6146)

